@@ -1,24 +1,7 @@
-// fstclosure.cc
-
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Author: riley@google.com (Michael Riley)
-// Modified: jpr@google.com (Jake Ratkiewicz) to use FstClass
-//
-// \file
 // Creates the Kleene closure of an FST.
-//
 
 #include <fst/script/closure.h>
 
@@ -26,6 +9,7 @@ DEFINE_bool(closure_plus, false,
             "Do not add the empty path (T+ instead of T*)");
 
 int main(int argc, char **argv) {
+  namespace s = fst::script;
   using fst::script::FstClass;
   using fst::script::MutableFstClass;
 
@@ -49,7 +33,8 @@ int main(int argc, char **argv) {
   fst::ClosureType closure_type =
       FLAGS_closure_plus ? fst::CLOSURE_PLUS : fst::CLOSURE_STAR;
 
-  fst::script::Closure(fst, closure_type);
+  s::Closure(fst, closure_type);
+
   fst->Write(out_fname);
 
   return 0;
