@@ -1,30 +1,16 @@
-// fstinfo.cc
-
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Author: riley@google.com (Michael Riley)
-// Modified: jpr@google.com (Jake Ratkiewicz) to use FstClass
-//
-// \file
 // Prints out various information about an FST such as number of states
 // and arcs and property values (see properties.h).
-//
 
 #include <fst/script/info.h>
 
-DEFINE_string(arc_filter, "any", "Arc filter: one of :"
-              " \"any\", \"epsilon\", \"iepsilon\", \"oepsilon\"");
+DEFINE_string(arc_filter, "any",
+              "Arc filter: one of:"
+              " \"any\", \"epsilon\", \"iepsilon\", \"oepsilon\"; "
+              "this only affects the counts of (co)accessible states, "
+              "connected states, and (strongly) connected components");
 DEFINE_string(info_type, "auto",
               "Info format: one of: \"auto\", \"long\", \"short\"");
 DEFINE_bool(pipe, false, "Send info to stderr, input to stdout");
