@@ -1,24 +1,7 @@
-// fstintersect.cc
-
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Author: riley@google.com (Michael Riley)
-// Modified: jpr@google.com (Jake Ratkiewicz) to use FstClass
-//
-// \file
 // Intersects two FSTs.
-//
 
 #include <fst/script/intersect.h>
 #include <fst/script/connect.h>
@@ -33,7 +16,6 @@ int main(int argc, char **argv) {
   using fst::script::FstClass;
   using fst::script::VectorFstClass;
 
-
   string usage = "Intersects two FSAs.\n\n  Usage: ";
   usage += argv[0];
   usage += " in1.fst in2.fst [out.fst]\n";
@@ -73,8 +55,8 @@ int main(int argc, char **argv) {
   } else if (FLAGS_compose_filter == "sequence") {
     compose_filter = fst::SEQUENCE_FILTER;
   } else {
-    LOG(ERROR) << argv[0] << "Unknown compose filter type: "
-               << FLAGS_compose_filter;
+    LOG(ERROR) << argv[0]
+               << "Unknown compose filter type: " << FLAGS_compose_filter;
     return 1;
   }
 
