@@ -1,24 +1,7 @@
-// fstprune.cc
-
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Author: allauzen@google.com (Cyril Allauzen)
-// Modified: jpr@google.com (Jake Ratkiewicz) to use FstClass
-//
-// \file
 // Prunes states and arcs of an FST w.r.t. the shortest path weight.
-//
 
 #include <fst/script/prune.h>
 
@@ -26,7 +9,6 @@ DEFINE_double(delta, fst::kDelta, "Comparison/quantization delta");
 DEFINE_int64(nstate, fst::kNoStateId, "State number threshold");
 DEFINE_string(weight, "", "Weight threshold");
 
-
 int main(int argc, char **argv) {
   namespace s = fst::script;
   using fst::script::FstClass;
@@ -50,11 +32,11 @@ int main(int argc, char **argv) {
   MutableFstClass *fst = MutableFstClass::Read(in_name, true);
   if (!fst) return 1;
 
-  WeightClass weight_threshold = FLAGS_weight.empty() ?
-      WeightClass::Zero() :
-      WeightClass(fst->WeightType(), FLAGS_weight);
+  WeightClass weight_threshold =
+      FLAGS_weight.empty() ? WeightClass::Zero(fst->WeightType())
+                           : WeightClass(fst->WeightType(), FLAGS_weight);
 
-  s::PruneOptions opts(weight_threshold, FLAGS_nstate, 0, FLAGS_delta);
+  s::PruneOptions opts(weight_threshold, FLAGS_nstate, nullptr, FLAGS_delta);
 
   s::Prune(fst, opts);
 
