@@ -1,20 +1,11 @@
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
+//
+// Performs the dynamic replacement of arcs in one FST with another FST,
+// allowing for the definition of FSTs analogous to RTNs.
 
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Author: johans@google.com (Johan Schalkwyk)
-// Modified: jpr@google.com (Jake Ratkiewicz) to use FstClass
-//
+#include <string>
+#include <vector>
 
 #include <fst/script/replace.h>
 
@@ -26,9 +17,9 @@ DEFINE_string(return_arc_labeling, "neither",
               "One of: \"input\", \"output\", \"both\", \"neither\" (default)");
 DEFINE_int64(return_label, 0, "Label to put on return arc");
 DEFINE_bool(epsilon_on_replace, false,
-            "For backward compatability: call/return arcs are epsilon arcs");
+            "For backwards compatibility: call/return arcs are epsilon arcs");
 
-// Assigns replace_label_type from enum values based on command line switches
+// Assigns replace_label_type from enum values based on command line switches.
 fst::ReplaceLabelType replace_type(string *arc_labeling, char *binname,
                                        string errmsg, bool epsilon_on_replace) {
   fst::ReplaceLabelType replace_label_type;
@@ -53,7 +44,8 @@ int main(int argc, char **argv) {
   using fst::script::FstClass;
   using fst::script::VectorFstClass;
 
-  string usage = "Recursively replaces FST arcs with other FST(s).\n\n"
+  string usage =
+      "Recursively replaces FST arcs with other FST(s).\n\n"
       "  Usage: ";
   usage += argv[0];
   usage += " root.fst rootlabel [rule1.fst label1 ...] [out.fst]\n";
@@ -71,30 +63,33 @@ int main(int argc, char **argv) {
   FstClass *ifst = FstClass::Read(in_fname);
   if (!ifst) return 1;
 
-  typedef int64 Label;
-  typedef pair<Label, const s::FstClass* > FstTuple;
-  vector<FstTuple> fst_tuples;
-  Label root = atoll(argv[2]);
-  fst_tuples.push_back(make_pair(root, ifst));
+  std::vector<s::LabelFstClassPair> pairs;
+  // Warning: if the root label is beyond the range of the underlying FST's
+  // labels, truncation will occur.
+  int64 root = atoll(argv[2]);
+  pairs.emplace_back(root, ifst);
 
   for (size_t i = 3; i < argc - 1; i += 2) {
     ifst = s::FstClass::Read(argv[i]);
     if (!ifst) return 1;
-    Label lab = atoll(argv[i + 1]);
-    fst_tuples.push_back(make_pair(lab, ifst));
+    // Warning: if the root label is beyond the range of the underlying FST's
+    // labels, truncation will occur.
+    int64 lab = atoll(argv[i + 1]);
+    pairs.emplace_back(lab, ifst);
   }
 
   fst::ReplaceLabelType call_label_type =
-     replace_type(&FLAGS_call_arc_labeling, argv[0], ": bad call ",
-                  FLAGS_epsilon_on_replace);
+      replace_type(&FLAGS_call_arc_labeling, argv[0], ": bad call ",
+                   FLAGS_epsilon_on_replace);
   fst::ReplaceLabelType return_label_type =
       replace_type(&FLAGS_return_arc_labeling, argv[0], ": bad return ",
                    FLAGS_epsilon_on_replace);
 
-  VectorFstClass ofst(ifst->ArcType());
   s::ReplaceOptions opts(root, call_label_type, return_label_type,
                          FLAGS_return_label);
-  s::Replace(fst_tuples, &ofst, opts);
+
+  VectorFstClass ofst(ifst->ArcType());
+  s::Replace(pairs, &ofst, opts);
 
   ofst.Write(out_fname);
 
