@@ -1,24 +1,7 @@
-// fstreweight.cc
-
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Author: allauzen@google.com (Cyril Allauzen)
-// Modified: jpr@google.com (Jake Ratkiewicz) to use FstClass
-//
-// \file
 // Reweights an FST.
-//
 
 #include <fst/script/reweight.h>
 #include <fst/script/text-io.h>
@@ -48,15 +31,16 @@ int main(int argc, char **argv) {
   MutableFstClass *fst = MutableFstClass::Read(in_fname, true);
   if (!fst) return 1;
 
-  vector<s::WeightClass> potential;
+  std::vector<s::WeightClass> potential;
   if (!s::ReadPotentials(fst->WeightType(), potentials_fname, &potential))
     return 1;
 
-  fst::ReweightType reweight_type = FLAGS_to_final ?
-      fst::REWEIGHT_TO_FINAL :
-      fst::REWEIGHT_TO_INITIAL;
+  fst::ReweightType reweight_type = FLAGS_to_final
+                                            ? fst::REWEIGHT_TO_FINAL
+                                            : fst::REWEIGHT_TO_INITIAL;
 
   s::Reweight(fst, potential, reweight_type);
+
   fst->Write(out_fname);
 
   return 0;
