@@ -1,33 +1,14 @@
-// main.cc
-
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Author: riley@google.com (Michael Riley)
-// Modified: jpr@google.com (Jake Ratkiewicz) to not use new arc-dispatch
-//
-// \file
-// Definitions and functions for invoking and using Far main
-// functions that support multiple and extensible arc types.
+// Definitions and functions for invoking and using Far main functions that
+// support multiple and extensible arc types.
 
 #include <string>
 #include <vector>
-using std::vector;
 
-#include <iostream>
-#include <fstream>
-#include <sstream>
 #include <fst/extensions/far/main.h>
+#include <fstream>
 
 namespace fst {
 
@@ -45,7 +26,6 @@ FarType FarTypeFromString(const string &str) {
   return type;
 }
 
-
 // Return the textual name  corresponding to a 'FarType;.
 string FarTypeToString(FarType type) {
   switch (type) {
@@ -86,18 +66,20 @@ FarTokenType StringToFarTokenType(const string &s) {
   }
 }
 
+void ExpandArgs(int argc, char **argv, int *argcp, char ***argvp) {
+}
 
 string LoadArcTypeFromFar(const string &far_fname) {
   FarHeader hdr;
 
   if (!hdr.Read(far_fname)) {
-    FSTERROR() << "Error reading FAR: " << far_fname;
+    LOG(ERROR) << "Error reading FAR: " << far_fname;
     return "";
   }
 
   string atype = hdr.ArcType();
   if (atype == "unknown") {
-    FSTERROR() << "Empty FST archive: " << far_fname;
+    LOG(ERROR) << "Empty FST archive: " << far_fname;
     return "";
   }
 
@@ -106,9 +88,10 @@ string LoadArcTypeFromFar(const string &far_fname) {
 
 string LoadArcTypeFromFst(const string &fst_fname) {
   FstHeader hdr;
-  ifstream in(fst_fname.c_str(), ifstream::in | ifstream::binary);
+  std::ifstream in(fst_fname.c_str(),
+                        std::ios_base::in | std::ios_base::binary);
   if (!hdr.Read(in, fst_fname)) {
-    FSTERROR() << "Error reading FST: " << fst_fname;
+    LOG(ERROR) << "Error reading FST: " << fst_fname;
     return "";
   }
 
