@@ -1,30 +1,15 @@
-
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Authors: allauzen@google.com (Cyril Allauzen)
-//          ttai@google.com (Terry Tai)
-//          jpr@google.com (Jake Ratkiewicz)
-
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
 
 #ifndef FST_EXTENSIONS_FAR_COMPILE_STRINGS_H_
 #define FST_EXTENSIONS_FAR_COMPILE_STRINGS_H_
 
 #include <libgen.h>
+#include <istream>
 #include <string>
 #include <vector>
-using std::vector;
 
+#include <fstream>
 #include <fst/extensions/far/far.h>
 #include <fst/string.h>
 
@@ -48,26 +33,26 @@ class StringReader {
 
   enum EntryType { LINE = 1, FILE = 2 };
 
-  StringReader(istream &istrm,
-               const string &source,
-               EntryType entry_type,
-               TokenType token_type,
-               bool allow_negative_labels,
-               const SymbolTable *syms = 0,
+  StringReader(std::istream &istrm, const string &source, EntryType entry_type,
+               TokenType token_type, bool allow_negative_labels,
+               const SymbolTable *syms = nullptr,
                Label unknown_label = kNoStateId)
-      : nline_(0), strm_(istrm), source_(source), entry_type_(entry_type),
-        token_type_(token_type), symbols_(syms), done_(false),
+      : nline_(0),
+        strm_(istrm),
+        source_(source),
+        entry_type_(entry_type),
+        token_type_(token_type),
+        symbols_(syms),
+        done_(false),
         compiler_(token_type, syms, unknown_label, allow_negative_labels) {
     Next();  // Initialize the reader to the first input.
   }
 
-  bool Done() {
-    return done_;
-  }
+  bool Done() { return done_; }
 
   void Next() {
     VLOG(1) << "Processing source " << source_ << " at line " << nline_;
-    if (!strm_) {                    // We're done if we have no more input.
+    if (!strm_) {  // We're done if we have no more input.
       done_ = true;
       return;
     }
@@ -97,31 +82,31 @@ class StringReader {
       return fst;
     } else {
       delete fst;
-      return NULL;
+      return nullptr;
     }
   }
 
-  CompactFst<A, StringCompactor<A> > *GetCompactFst(bool keep_symbols = false) {
-    CompactFst<A, StringCompactor<A> > *fst;
+  CompactFst<A, StringCompactor<A>> *GetCompactFst(bool keep_symbols = false) {
+    CompactFst<A, StringCompactor<A>> *fst;
     if (keep_symbols) {
       VectorFst<A> tmp;
       tmp.SetInputSymbols(symbols_);
       tmp.SetOutputSymbols(symbols_);
-      fst = new CompactFst<A, StringCompactor<A> >(tmp);
+      fst = new CompactFst<A, StringCompactor<A>>(tmp);
     } else {
-      fst = new CompactFst<A, StringCompactor<A> >;
+      fst = new CompactFst<A, StringCompactor<A>>;
     }
     if (compiler_(content_, fst)) {
       return fst;
     } else {
       delete fst;
-      return NULL;
+      return nullptr;
     }
   }
 
  private:
   size_t nline_;
-  istream &strm_;
+  std::istream &strm_;
   string source_;
   EntryType entry_type_;
   TokenType token_type_;
@@ -138,28 +123,21 @@ class StringReader {
 int KeySize(const char *filename);
 
 template <class Arc>
-void FarCompileStrings(const vector<string> &in_fnames,
-                       const string &out_fname,
-                       const string &fst_type,
-                       const FarType &far_type,
-                       int32 generate_keys,
-                       FarEntryType fet,
-                       FarTokenType tt,
+void FarCompileStrings(const std::vector<string> &in_fnames,
+                       const string &out_fname, const string &fst_type,
+                       const FarType &far_type, int32 generate_keys,
+                       FarEntryType fet, FarTokenType tt,
                        const string &symbols_fname,
-                       const string &unknown_symbol,
-                       bool keep_symbols,
-                       bool initial_symbols,
-                       bool allow_negative_labels,
-                       bool file_list_input,
-                       const string &key_prefix,
-                       const string &key_suffix) {
+                       const string &unknown_symbol, bool keep_symbols,
+                       bool initial_symbols, bool allow_negative_labels,
+                       const string &key_prefix, const string &key_suffix) {
   typename StringReader<Arc>::EntryType entry_type;
   if (fet == FET_LINE) {
     entry_type = StringReader<Arc>::LINE;
   } else if (fet == FET_FILE) {
     entry_type = StringReader<Arc>::FILE;
   } else {
-    FSTERROR() << "FarCompileStrings: unknown entry type";
+    FSTERROR() << "FarCompileStrings: Unknown entry type";
     return;
   }
 
@@ -171,7 +149,7 @@ void FarCompileStrings(const vector<string> &in_fnames,
   } else if (tt == FTT_UTF8) {
     token_type = StringCompiler<Arc>::UTF8;
   } else {
-    FSTERROR() << "FarCompileStrings: unknown token type";
+    FSTERROR() << "FarCompileStrings: Unknown token type";
     return;
   }
 
@@ -181,8 +159,7 @@ void FarCompileStrings(const vector<string> &in_fnames,
   } else if (fst_type == "compact") {
     compact = true;
   } else {
-    FSTERROR() << "FarCompileStrings: unknown fst type: "
-               << fst_type;
+    FSTERROR() << "FarCompileStrings: Unknown Fst type: " << fst_type;
     return;
   }
 
@@ -193,83 +170,69 @@ void FarCompileStrings(const vector<string> &in_fnames,
     opts.allow_negative = allow_negative_labels;
     syms = SymbolTable::ReadText(symbols_fname, opts);
     if (!syms) {
-      FSTERROR() << "FarCompileStrings: error reading symbol table: "
+      LOG(ERROR) << "FarCompileStrings: Error reading symbol table: "
                  << symbols_fname;
       return;
     }
     if (!unknown_symbol.empty()) {
       unknown_label = syms->Find(unknown_symbol);
       if (unknown_label == kNoLabel) {
-        FSTERROR() << "FarCompileStrings: unknown label \"" << unknown_label
+        FSTERROR() << "FarCompileStrings: Label \"" << unknown_label
                    << "\" missing from symbol table: " << symbols_fname;
         return;
       }
     }
   }
 
-  FarWriter<Arc> *far_writer =
-      FarWriter<Arc>::Create(out_fname, far_type);
+  FarWriter<Arc> *far_writer = FarWriter<Arc>::Create(out_fname, far_type);
   if (!far_writer) return;
 
-  vector<string> inputs;
-  if (file_list_input) {
-    for (int i = 0; i < in_fnames.size(); ++i) {
-      istream *istrm = in_fnames.empty() ? &cin :
-          new ifstream(in_fnames[i].c_str());
-      string str;
-      while (getline(*istrm, str))
-        inputs.push_back(str);
-      if (!in_fnames.empty())
-        delete istrm;
-    }
-  } else {
-    inputs = in_fnames;
-  }
-
-  for (int i = 0, n = 0; i < inputs.size(); ++i) {
-    if (generate_keys == 0 && inputs[i].empty()) {
-      FSTERROR() << "FarCompileStrings: read from a file instead of stdin or"
+  for (int i = 0, n = 0; i < in_fnames.size(); ++i) {
+    if (generate_keys == 0 && in_fnames[i].empty()) {
+      FSTERROR() << "FarCompileStrings: Read from a file instead of stdin or"
                  << " set the --generate_keys flags.";
       delete far_writer;
       delete syms;
       return;
     }
-    int key_size = generate_keys ? generate_keys :
-        (entry_type == StringReader<Arc>::FILE ? 1 :
-         KeySize(inputs[i].c_str()));
-    istream *istrm = inputs[i].empty() ? &cin :
-        new ifstream(inputs[i].c_str());
+    int key_size =
+        generate_keys ? generate_keys : (entry_type == StringReader<Arc>::FILE
+                                             ? 1
+                                             : KeySize(in_fnames[i].c_str()));
+    std::istream *istrm =
+        in_fnames[i].empty() ? &std::cin : new std::ifstream(in_fnames[i]);
 
     bool keep_syms = keep_symbols;
     for (StringReader<Arc> reader(
-             *istrm, inputs[i].empty() ? "stdin" : inputs[i],
-             entry_type, token_type, allow_negative_labels,
-             syms, unknown_label);
-         !reader.Done();
-         reader.Next()) {
+             *istrm, in_fnames[i].empty() ? "stdin" : in_fnames[i], entry_type,
+             token_type, allow_negative_labels, syms, unknown_label);
+         !reader.Done(); reader.Next()) {
       ++n;
       const Fst<Arc> *fst;
       if (compact)
         fst = reader.GetCompactFst(keep_syms);
       else
         fst = reader.GetVectorFst(keep_syms);
-      if (initial_symbols)
-        keep_syms = false;
+      if (initial_symbols) keep_syms = false;
       if (!fst) {
-        FSTERROR() << "FarCompileStrings: compiling string number " << n
-                   << " in file " << inputs[i] << " failed with token_type = "
-                   << (tt == FTT_BYTE ? "byte" :
-                       (tt == FTT_UTF8 ? "utf8" :
-                        (tt == FTT_SYMBOL ? "symbol" : "unknown")))
+        FSTERROR() << "FarCompileStrings: Compiling string number " << n
+                   << " in file " << in_fnames[i]
+                   << " failed with token_type = "
+                   << (tt == FTT_BYTE
+                           ? "byte"
+                           : (tt == FTT_UTF8
+                                  ? "utf8"
+                                  : (tt == FTT_SYMBOL ? "symbol" : "unknown")))
                    << " and entry_type = "
-                   << (fet == FET_LINE ? "line" :
-                       (fet == FET_FILE ? "file" : "unknown"));
+                   << (fet == FET_LINE
+                           ? "line"
+                           : (fet == FET_FILE ? "file" : "unknown"));
         delete far_writer;
         delete syms;
-        if (!inputs[i].empty()) delete istrm;
+        if (!in_fnames[i].empty()) delete istrm;
         return;
       }
-      ostringstream keybuf;
+      std::ostringstream keybuf;
       keybuf.width(key_size);
       keybuf.fill('0');
       keybuf << n;
@@ -277,8 +240,8 @@ void FarCompileStrings(const vector<string> &in_fnames,
       if (generate_keys > 0) {
         key = keybuf.str();
       } else {
-        char* filename = new char[inputs[i].size() + 1];
-        strcpy(filename, inputs[i].c_str());
+        char *filename = new char[in_fnames[i].size() + 1];
+        strcpy(filename, in_fnames[i].c_str());
         key = basename(filename);
         if (entry_type != StringReader<Arc>::FILE) {
           key += "-";
@@ -289,10 +252,8 @@ void FarCompileStrings(const vector<string> &in_fnames,
       far_writer->Add(key_prefix + key + key_suffix, *fst);
       delete fst;
     }
-    if (generate_keys == 0)
-      n = 0;
-    if (!inputs[i].empty())
-      delete istrm;
+    if (generate_keys == 0) n = 0;
+    if (!in_fnames[i].empty()) delete istrm;
   }
 
   delete far_writer;
@@ -300,5 +261,4 @@ void FarCompileStrings(const vector<string> &in_fnames,
 
 }  // namespace fst
 
-
 #endif  // FST_EXTENSIONS_FAR_COMPILE_STRINGS_H_
