@@ -1,25 +1,12 @@
-// matcher-fst.h
-
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Author: riley@google.com (Michael Riley)
-//
-// \file
 // Class to add a matcher to an FST.
 
-#ifndef FST_LIB_MATCHER_FST_FST_H__
-#define FST_LIB_MATCHER_FST_FST_H__
+#ifndef FST_LIB_MATCHER_FST_H_
+#define FST_LIB_MATCHER_FST_H_
+
+#include <memory>
 
 #include <fst/add-on.h>
 #include <fst/const-fst.h>
@@ -53,13 +40,8 @@ namespace fst {
 //   MatcherData(const MatcherData &);
 //   //
 //   // Required I/O methods.
-//   static MatcherData *Read(istream &istrm);
-//   bool Write(ostream &ostrm);
-//
-//   // Required reference counting.
-//   int RefCount() const;
-//   int IncrRefCount();
-//   int DecrRefCount();
+//   static MatcherData *Read(std::istream &istrm, const FstReadOptions& opts);
+//   bool Write(std::ostream &ostrm, const FstWriteOptions& opts) const;
 // };
 
 // Default MatcherFst initializer - does nothing.
@@ -68,21 +50,19 @@ class NullMatcherFstInit {
  public:
   typedef AddOnPair<typename M::MatcherData, typename M::MatcherData> D;
   typedef AddOnImpl<typename M::FST, D> Impl;
-  NullMatcherFstInit(Impl **) {}
+  explicit NullMatcherFstInit(std::shared_ptr<Impl> *impl) {}
 };
 
 // Class to add a matcher M to an Fst F. Creates a new Fst of type name N.
 // Optional function object I can be used to initialize the Fst.
 // Parameter A allows defining the kind of add-on to use.
-template <class F, class M, const char* N,
-          class I = NullMatcherFstInit<M>,
-          class A = AddOnPair<typename M::MatcherData,
-                              typename M::MatcherData> >
-class MatcherFst
-    : public ImplToExpandedFst<AddOnImpl<F, A> > {
+template <class F, class M, const char *N, class I = NullMatcherFstInit<M>,
+          class A =
+              AddOnPair<typename M::MatcherData, typename M::MatcherData>>
+class MatcherFst : public ImplToExpandedFst<AddOnImpl<F, A>> {
  public:
-  friend class StateIterator< MatcherFst<F, M, N, I, A> >;
-  friend class ArcIterator< MatcherFst<F, M, N, I, A> >;
+  friend class StateIterator<MatcherFst<F, M, N, I, A>>;
+  friend class ArcIterator<MatcherFst<F, M, N, I, A>>;
 
   typedef F FST;
   typedef M FstMatcher;
@@ -91,7 +71,7 @@ class MatcherFst
   typedef A D;
   typedef AddOnImpl<F, D> Impl;
 
-  MatcherFst() : ImplToExpandedFst<Impl>(new Impl(F(), N)) {}
+  MatcherFst() : ImplToExpandedFst<Impl>(std::make_shared<Impl>(F(), N)) {}
 
   explicit MatcherFst(const F &fst)
       : ImplToExpandedFst<Impl>(CreateImpl(fst, N)) {}
@@ -104,105 +84,112 @@ class MatcherFst
       : ImplToExpandedFst<Impl>(fst, safe) {}
 
   // Get a copy of this MatcherFst. See Fst<>::Copy() for further doc.
-  virtual MatcherFst<F, M, N, I, A> *Copy(bool safe = false) const {
+  MatcherFst<F, M, N, I, A> *Copy(bool safe = false) const override {
     return new MatcherFst<F, M, N, I, A>(*this, safe);
   }
 
-  // Read a MatcherFst from an input stream; return NULL on error
-  static MatcherFst<F, M, N, I, A> *Read(istream &strm,
-                                      const FstReadOptions &opts) {
+  // Read a MatcherFst from an input stream; return nullptr on error
+  static MatcherFst<F, M, N, I, A> *Read(std::istream &strm,
+                                         const FstReadOptions &opts) {
     Impl *impl = Impl::Read(strm, opts);
-    return impl ? new MatcherFst<F, M, N, I, A>(impl) : 0;
+    return impl ? new MatcherFst<F, M, N, I, A>(std::shared_ptr<Impl>(impl))
+                : nullptr;
   }
 
-  // Read a MatcherFst from a file; return NULL on error
+  // Read a MatcherFst from a file; return nullptr on error
   // Empty filename reads from standard input
   static MatcherFst<F, M, N, I, A> *Read(const string &filename) {
     Impl *impl = ImplToExpandedFst<Impl>::Read(filename);
-    return impl ? new MatcherFst<F, M, N, I, A>(impl) : 0;
+    return impl ? new MatcherFst<F, M, N, I, A>(std::shared_ptr<Impl>(impl))
+                : nullptr;
   }
 
-  virtual bool Write(ostream &strm, const FstWriteOptions &opts) const {
+  bool Write(std::ostream &strm, const FstWriteOptions &opts) const override {
     return GetImpl()->Write(strm, opts);
   }
 
-  virtual bool Write(const string &filename) const {
+  bool Write(const string &filename) const override {
     return Fst<Arc>::WriteFile(filename);
   }
 
-  virtual void InitStateIterator(StateIteratorData<Arc> *data) const {
+  void InitStateIterator(StateIteratorData<Arc> *data) const override {
     return GetImpl()->InitStateIterator(data);
   }
 
-  virtual void InitArcIterator(StateId s, ArcIteratorData<Arc> *data) const {
+  void InitArcIterator(StateId s, ArcIteratorData<Arc> *data) const override {
     return GetImpl()->InitArcIterator(s, data);
   }
 
-  virtual M *InitMatcher(MatchType match_type) const {
-    return new M(GetFst(), match_type, GetData(match_type));
+  M *InitMatcher(MatchType match_type) const override {
+    return new M(GetFst(), match_type, GetSharedData(match_type));
   }
 
-  // Allows access to MatcherFst components.
-  Impl *GetImpl() const {
-    return ImplToFst<Impl, ExpandedFst<Arc> >::GetImpl();
+  const F &GetFst() const { return GetImpl()->GetFst(); }
+
+  const D *GetAddOn() const { return GetImpl()->GetAddOn(); }
+
+  std::shared_ptr<D> GetSharedAddOn() const {
+    return GetImpl()->GetSharedAddOn();
   }
 
-  F& GetFst() const { return GetImpl()->GetFst(); }
-
-  typename M::MatcherData *GetData(MatchType match_type) const {
-    D *data = GetImpl()->GetAddOn();
+  const typename M::MatcherData *GetData(MatchType match_type) const {
+    const D *data = GetAddOn();
     return match_type == MATCH_INPUT ? data->First() : data->Second();
   }
 
- private:
-  static Impl *CreateImpl(const F &fst, const string &name) {
+  std::shared_ptr<typename M::MatcherData> GetSharedData(
+      MatchType match_type) const {
+    const D *data = GetAddOn();
+    return match_type == MATCH_INPUT ? data->SharedFirst()
+                                     : data->SharedSecond();
+  }
+
+ protected:
+  using ImplToFst<Impl, ExpandedFst<Arc>>::GetImpl;
+
+  static std::shared_ptr<Impl> CreateImpl(const F &fst, const string &name) {
     M imatcher(fst, MATCH_INPUT);
     M omatcher(fst, MATCH_OUTPUT);
-    D *data = new D(imatcher.GetData(), omatcher.GetData());
-    Impl *impl = new Impl(fst, name);
+    std::shared_ptr<D> data =
+        std::make_shared<D>(imatcher.GetSharedData(), omatcher.GetSharedData());
+    std::shared_ptr<Impl> impl = std::make_shared<Impl>(fst, name);
     impl->SetAddOn(data);
     I init(&impl);
-    data->DecrRefCount();
     return impl;
   }
 
-  static Impl *CreateImpl(const Fst<Arc> &fst, const string &name) {
+  static std::shared_ptr<Impl> CreateImpl(const Fst<Arc> &fst,
+                                          const string &name) {
     F ffst(fst);
     return CreateImpl(ffst, name);
   }
 
-  explicit MatcherFst(Impl *impl) : ImplToExpandedFst<Impl>(impl) {}
-
-  // Makes visible to friends.
-  void SetImpl(Impl *impl, bool own_impl = true) {
-    ImplToFst< Impl, ExpandedFst<Arc> >::SetImpl(impl, own_impl);
-  }
+  explicit MatcherFst(std::shared_ptr<Impl> impl)
+      : ImplToExpandedFst<Impl>(impl) {}
 
+ private:
   void operator=(const MatcherFst<F, M, N, I, A> &fst);  // disallow
 };
 
-
 // Specialization fo MatcherFst.
-template <class F, class M, const char* N, class I>
-class StateIterator< MatcherFst<F, M, N, I> > : public StateIterator<F> {
+template <class F, class M, const char *N, class I>
+class StateIterator<MatcherFst<F, M, N, I>> : public StateIterator<F> {
  public:
-  explicit StateIterator(const MatcherFst<F, M, N, I> &fst) :
-      StateIterator<F>(fst.GetImpl()->GetFst()) {}
+  explicit StateIterator(const MatcherFst<F, M, N, I> &fst)
+      : StateIterator<F>(fst.GetImpl()->GetFst()) {}
 };
 
-
 // Specialization for MatcherFst.
-template <class F, class M, const char* N, class I>
-class ArcIterator< MatcherFst<F, M, N, I> > : public ArcIterator<F> {
+template <class F, class M, const char *N, class I>
+class ArcIterator<MatcherFst<F, M, N, I>> : public ArcIterator<F> {
  public:
   ArcIterator(const MatcherFst<F, M, N, I> &fst, typename F::Arc::StateId s)
       : ArcIterator<F>(fst.GetImpl()->GetFst(), s) {}
 };
 
-
 // Specialization for MatcherFst
-template <class F, class M, const char* N, class I>
-class Matcher< MatcherFst<F, M, N, I> > {
+template <class F, class M, const char *N, class I>
+class Matcher<MatcherFst<F, M, N, I>> {
  public:
   typedef MatcherFst<F, M, N, I> FST;
   typedef typename F::Arc Arc;
@@ -213,21 +200,17 @@ class Matcher< MatcherFst<F, M, N, I> > {
     matcher_ = fst.InitMatcher(match_type);
   }
 
-  Matcher(const Matcher<FST> &matcher) {
-    matcher_ = matcher.matcher_->Copy();
-  }
+  Matcher(const Matcher<FST> &matcher) { matcher_ = matcher.matcher_->Copy(); }
 
   ~Matcher() { delete matcher_; }
 
-  Matcher<FST> *Copy() const {
-    return new Matcher<FST>(*this);
-  }
+  Matcher<FST> *Copy() const { return new Matcher<FST>(*this); }
 
   MatchType Type(bool test) const { return matcher_->Type(test); }
   void SetState(StateId s) { matcher_->SetState(s); }
   bool Find(Label label) { return matcher_->Find(label); }
   bool Done() const { return matcher_->Done(); }
-  const Arc& Value() const { return matcher_->Value(); }
+  const Arc &Value() const { return matcher_->Value(); }
   void Next() { matcher_->Next(); }
   uint64 Properties(uint64 props) const { return matcher_->Properties(props); }
   uint32 Flags() const { return matcher_->Flags(); }
@@ -238,10 +221,9 @@ class Matcher< MatcherFst<F, M, N, I> > {
   void operator=(const Matcher<Arc> &);  // disallow
 };
 
-
 // Specialization for MatcherFst
-template <class F, class M, const char* N, class I>
-class LookAheadMatcher< MatcherFst<F, M, N, I> > {
+template <class F, class M, const char *N, class I>
+class LookAheadMatcher<MatcherFst<F, M, N, I>> {
  public:
   typedef MatcherFst<F, M, N, I> FST;
   typedef typename F::Arc Arc;
@@ -268,7 +250,7 @@ class LookAheadMatcher< MatcherFst<F, M, N, I> > {
   void SetState(StateId s) { matcher_->SetState(s); }
   bool Find(Label label) { return matcher_->Find(label); }
   bool Done() const { return matcher_->Done(); }
-  const Arc& Value() const { return matcher_->Value(); }
+  const Arc &Value() const { return matcher_->Value(); }
   void Next() { matcher_->Next(); }
   const FST &GetFst() const { return matcher_->GetFst(); }
   uint64 Properties(uint64 props) const { return matcher_->Properties(props); }
@@ -289,7 +271,7 @@ class LookAheadMatcher< MatcherFst<F, M, N, I> > {
     return matcher_->LookAheadPrefix(arc);
   }
 
-  void InitLookAheadFst(const Fst<Arc>& fst, bool copy = false) {
+  void InitLookAheadFst(const Fst<Arc> &fst, bool copy = false) {
     matcher_->InitLookAheadFst(fst, copy);
   }
 
@@ -307,53 +289,52 @@ class LookAheadMatcher< MatcherFst<F, M, N, I> > {
 extern const char arc_lookahead_fst_type[];
 
 typedef MatcherFst<ConstFst<StdArc>,
-                   ArcLookAheadMatcher<SortedMatcher<ConstFst<StdArc> > >,
+                   ArcLookAheadMatcher<SortedMatcher<ConstFst<StdArc>> >,
                    arc_lookahead_fst_type> StdArcLookAheadFst;
 
 typedef MatcherFst<ConstFst<LogArc>,
-                   ArcLookAheadMatcher<SortedMatcher<ConstFst<LogArc> > >,
+                   ArcLookAheadMatcher<SortedMatcher<ConstFst<LogArc>> >,
                    arc_lookahead_fst_type> LogArcLookAheadFst;
 
-
 // Label look-ahead matchers
 extern const char ilabel_lookahead_fst_type[];
 extern const char olabel_lookahead_fst_type[];
 
-static const uint32 ilabel_lookahead_flags = kInputLookAheadMatcher |
-    kLookAheadWeight | kLookAheadPrefix |
+static const uint32 ilabel_lookahead_flags =
+    kInputLookAheadMatcher | kLookAheadWeight | kLookAheadPrefix |
     kLookAheadEpsilons | kLookAheadNonEpsilonPrefix;
-static const uint32 olabel_lookahead_flags = kOutputLookAheadMatcher |
-    kLookAheadWeight | kLookAheadPrefix |
+static const uint32 olabel_lookahead_flags =
+    kOutputLookAheadMatcher | kLookAheadWeight | kLookAheadPrefix |
     kLookAheadEpsilons | kLookAheadNonEpsilonPrefix;
 
-typedef MatcherFst<ConstFst<StdArc>,
-                   LabelLookAheadMatcher<SortedMatcher<ConstFst<StdArc> >,
-                                         ilabel_lookahead_flags,
-                                         FastLogAccumulator<StdArc> >,
-                   ilabel_lookahead_fst_type,
-                   LabelLookAheadRelabeler<StdArc> > StdILabelLookAheadFst;
+typedef MatcherFst<
+    ConstFst<StdArc>,
+    LabelLookAheadMatcher<SortedMatcher<ConstFst<StdArc>>,
+                          ilabel_lookahead_flags, FastLogAccumulator<StdArc>>,
+    ilabel_lookahead_fst_type,
+    LabelLookAheadRelabeler<StdArc>> StdILabelLookAheadFst;
 
-typedef MatcherFst<ConstFst<LogArc>,
-                   LabelLookAheadMatcher<SortedMatcher<ConstFst<LogArc> >,
-                                         ilabel_lookahead_flags,
-                                         FastLogAccumulator<LogArc> >,
-                   ilabel_lookahead_fst_type,
-                   LabelLookAheadRelabeler<LogArc> > LogILabelLookAheadFst;
+typedef MatcherFst<
+    ConstFst<LogArc>,
+    LabelLookAheadMatcher<SortedMatcher<ConstFst<LogArc>>,
+                          ilabel_lookahead_flags, FastLogAccumulator<LogArc>>,
+    ilabel_lookahead_fst_type,
+    LabelLookAheadRelabeler<LogArc>> LogILabelLookAheadFst;
 
-typedef MatcherFst<ConstFst<StdArc>,
-                   LabelLookAheadMatcher<SortedMatcher<ConstFst<StdArc> >,
-                                         olabel_lookahead_flags,
-                                         FastLogAccumulator<StdArc> >,
-                   olabel_lookahead_fst_type,
-                   LabelLookAheadRelabeler<StdArc> > StdOLabelLookAheadFst;
+typedef MatcherFst<
+    ConstFst<StdArc>,
+    LabelLookAheadMatcher<SortedMatcher<ConstFst<StdArc>>,
+                          olabel_lookahead_flags, FastLogAccumulator<StdArc>>,
+    olabel_lookahead_fst_type,
+    LabelLookAheadRelabeler<StdArc>> StdOLabelLookAheadFst;
 
-typedef MatcherFst<ConstFst<LogArc>,
-                   LabelLookAheadMatcher<SortedMatcher<ConstFst<LogArc> >,
-                                         olabel_lookahead_flags,
-                                         FastLogAccumulator<LogArc> >,
-                   olabel_lookahead_fst_type,
-                   LabelLookAheadRelabeler<LogArc> > LogOLabelLookAheadFst;
+typedef MatcherFst<
+    ConstFst<LogArc>,
+    LabelLookAheadMatcher<SortedMatcher<ConstFst<LogArc>>,
+                          olabel_lookahead_flags, FastLogAccumulator<LogArc>>,
+    olabel_lookahead_fst_type,
+    LabelLookAheadRelabeler<LogArc>> LogOLabelLookAheadFst;
 
 }  // namespace fst
 
-#endif  // FST_LIB_MATCHER_FST_FST_H__
+#endif  // FST_LIB_MATCHER_FST_H_
