@@ -1,37 +1,17 @@
-// compile.h
-
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
+// See www.openfst.org for extensive documentation on this weighted
+// finite-state transducer library.
 //
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-//
-// Copyright 2005-2010 Google, Inc.
-// Author: riley@google.com (Michael Riley)
-//
-// \file
-// Class to to compile a binary Fst from textual input.
+// Class to to compile a binary FST from textual input.
 
 #ifndef FST_SCRIPT_COMPILE_IMPL_H_
 #define FST_SCRIPT_COMPILE_IMPL_H_
 
-#include <unordered_map>
-using std::unordered_map;
-using std::unordered_multimap;
+#include <iostream>
 #include <sstream>
 #include <string>
+#include <unordered_map>
 #include <vector>
-using std::vector;
 
-#include <iostream>
-#include <fstream>
-#include <sstream>
 #include <fst/fst.h>
 #include <fst/util.h>
 #include <fst/vector-fst.h>
@@ -43,7 +23,8 @@ namespace fst {
 // Compile a binary Fst from textual input, helper class for fstcompile.cc
 // WARNING: Stand-alone use of this class not recommended, most code should
 // read/write using the binary format which is much more efficient.
-template <class A> class FstCompiler {
+template <class A>
+class FstCompiler {
  public:
   typedef A Arc;
   typedef typename A::StateId StateId;
@@ -56,13 +37,13 @@ template <class A> class FstCompiler {
   // to the symbol tables.  This is only useful if you set the (i/o)keep flag
   // to attach the final symbol table, or use the accessors.  (The input
   // symbol tables are const and therefore not changed.)
-  FstCompiler(istream &istrm, const string &source,  // NOLINT
+  FstCompiler(std::istream &istrm, const string &source,  // NOLINT
               const SymbolTable *isyms, const SymbolTable *osyms,
               const SymbolTable *ssyms, bool accep, bool ikeep,
               bool okeep, bool nkeep, bool allow_negative_labels = false) {
-    SymbolTable* misyms = isyms ? isyms->Copy() : NULL;
-    SymbolTable* mosyms = osyms ? osyms->Copy() : NULL;
-    SymbolTable* mssyms = ssyms ? ssyms->Copy() : NULL;
+    SymbolTable* misyms = isyms ? isyms->Copy() : nullptr;
+    SymbolTable* mosyms = osyms ? osyms->Copy() : nullptr;
+    SymbolTable* mssyms = ssyms ? ssyms->Copy() : nullptr;
     Init(istrm, source, misyms, mosyms, mssyms, accep, ikeep, okeep, nkeep,
          allow_negative_labels, false);
     delete mssyms;
@@ -70,19 +51,18 @@ template <class A> class FstCompiler {
     delete misyms;
   }
 
-  FstCompiler(istream &istrm, const string &source,  // NOLINT
-              SymbolTable *isyms, SymbolTable *osyms,
-              SymbolTable *ssyms, bool accep, bool ikeep,
-              bool okeep, bool nkeep, bool allow_negative_labels,
-              bool add_symbols) {
+  FstCompiler(std::istream &istrm, const string &source,  // NOLINT
+              SymbolTable *isyms, SymbolTable *osyms, SymbolTable *ssyms,
+              bool accep, bool ikeep, bool okeep, bool nkeep,
+              bool allow_negative_labels, bool add_symbols) {
     Init(istrm, source, isyms, osyms, ssyms, accep, ikeep, okeep, nkeep,
          allow_negative_labels, add_symbols);
   }
 
-  void Init(istream &istrm, const string &source, SymbolTable *isyms,  // NOLINT
-            SymbolTable *osyms, SymbolTable *ssyms, bool accep, bool ikeep,
-            bool okeep, bool nkeep, bool allow_negative_labels,
-            bool add_symbols) {
+  void Init(std::istream &istrm, const string &source,  // NOLINT
+            SymbolTable *isyms, SymbolTable *osyms, SymbolTable *ssyms,
+            bool accep, bool ikeep, bool okeep, bool nkeep,
+            bool allow_negative_labels, bool add_symbols) {
     nline_ = 0;
     source_ = source;
     isyms_ = isyms;
@@ -95,82 +75,72 @@ template <class A> class FstCompiler {
     char line[kLineLen];
     while (istrm.getline(line, kLineLen)) {
       ++nline_;
-      vector<char *> col;
+      std::vector<char *> col;
       string separator = FLAGS_fst_field_separator + "\n";
       SplitToVector(line, separator.c_str(), &col, true);
       if (col.size() == 0 || col[0][0] == '\0')  // empty line
         continue;
-      if (col.size() > 5 ||
-          (col.size() > 4 && accep) ||
+      if (col.size() > 5 || (col.size() > 4 && accep) ||
           (col.size() == 3 && !accep)) {
-        FSTERROR() << "FstCompiler: Bad number of columns, source = "
-                   << source_
+        FSTERROR() << "FstCompiler: Bad number of columns, source = " << source_
                    << ", line = " << nline_;
         fst_.SetProperties(kError, kError);
         return;
       }
       StateId s = StrToStateId(col[0]);
-      while (s >= fst_.NumStates())
-        fst_.AddState();
-      if (nline_ == 1)
-        fst_.SetStart(s);
+      while (s >= fst_.NumStates()) fst_.AddState();
+      if (nline_ == 1) fst_.SetStart(s);
 
       Arc arc;
       StateId d = s;
       switch (col.size()) {
-      case 1:
-        fst_.SetFinal(s, Weight::One());
-        break;
-      case 2:
-        fst_.SetFinal(s, StrToWeight(col[1], true));
-        break;
-      case 3:
-        arc.nextstate = d = StrToStateId(col[1]);
-        arc.ilabel = StrToILabel(col[2]);
-        arc.olabel = arc.ilabel;
-        arc.weight = Weight::One();
-        fst_.AddArc(s, arc);
-        break;
-      case 4:
-        arc.nextstate = d = StrToStateId(col[1]);
-        arc.ilabel = StrToILabel(col[2]);
-        if (accep) {
+        case 1:
+          fst_.SetFinal(s, Weight::One());
+          break;
+        case 2:
+          fst_.SetFinal(s, StrToWeight(col[1], true));
+          break;
+        case 3:
+          arc.nextstate = d = StrToStateId(col[1]);
+          arc.ilabel = StrToILabel(col[2]);
           arc.olabel = arc.ilabel;
-          arc.weight = StrToWeight(col[3], true);
-        } else {
-          arc.olabel = StrToOLabel(col[3]);
           arc.weight = Weight::One();
-        }
-        fst_.AddArc(s, arc);
-        break;
-      case 5:
-        arc.nextstate = d = StrToStateId(col[1]);
-        arc.ilabel = StrToILabel(col[2]);
-        arc.olabel = StrToOLabel(col[3]);
-        arc.weight = StrToWeight(col[4], true);
-        fst_.AddArc(s, arc);
+          fst_.AddArc(s, arc);
+          break;
+        case 4:
+          arc.nextstate = d = StrToStateId(col[1]);
+          arc.ilabel = StrToILabel(col[2]);
+          if (accep) {
+            arc.olabel = arc.ilabel;
+            arc.weight = StrToWeight(col[3], true);
+          } else {
+            arc.olabel = StrToOLabel(col[3]);
+            arc.weight = Weight::One();
+          }
+          fst_.AddArc(s, arc);
+          break;
+        case 5:
+          arc.nextstate = d = StrToStateId(col[1]);
+          arc.ilabel = StrToILabel(col[2]);
+          arc.olabel = StrToOLabel(col[3]);
+          arc.weight = StrToWeight(col[4], true);
+          fst_.AddArc(s, arc);
       }
-      while (d >= fst_.NumStates())
-        fst_.AddState();
+      while (d >= fst_.NumStates()) fst_.AddState();
     }
-    if (ikeep)
-      fst_.SetInputSymbols(isyms);
-    if (okeep)
-      fst_.SetOutputSymbols(osyms);
+    if (ikeep) fst_.SetInputSymbols(isyms);
+    if (okeep) fst_.SetOutputSymbols(osyms);
   }
 
-  const VectorFst<A> &Fst() const {
-    return fst_;
-  }
+  const VectorFst<A> &Fst() const { return fst_; }
 
  private:
   // Maximum line length in text file.
   static const int kLineLen = 8096;
 
-  int64 StrToId(const char *s, SymbolTable *syms,
-                const char *name, bool allow_negative = false) const {
-    int64 n = 0;
-
+  StateId StrToId(const char *s, SymbolTable *syms, const char *name,
+                  bool allow_negative = false) const {
+    StateId n = 0;
     if (syms) {
       n = (add_symbols_) ? syms->AddSymbol(s) : syms->Find(s);
       if (n == -1 || (!allow_negative && n < 0)) {
@@ -194,12 +164,10 @@ template <class A> class FstCompiler {
 
   StateId StrToStateId(const char *s) {
     StateId n = StrToId(s, ssyms_, "state ID");
-
-    if (keep_state_numbering_)
-      return n;
-
+    if (keep_state_numbering_) return n;
     // remap state IDs to make dense set
-    typename unordered_map<StateId, StateId>::const_iterator it = states_.find(n);
+    typename std::unordered_map<StateId, StateId>::const_iterator it =
+        states_.find(n);
     if (it == states_.end()) {
       states_[n] = nstates_;
       return nstates_++;
@@ -218,7 +186,7 @@ template <class A> class FstCompiler {
 
   Weight StrToWeight(const char *s, bool allow_zero) const {
     Weight w;
-    istringstream strm(s);
+    std::istringstream strm(s);
     strm >> w;
     if (!strm || (!allow_zero && w == Weight::Zero())) {
       FSTERROR() << "FstCompiler: Bad weight = \"" << s
@@ -232,14 +200,14 @@ template <class A> class FstCompiler {
   mutable VectorFst<A> fst_;
   size_t nline_;
   string source_;                      // text FST source name
-  SymbolTable *isyms_;           // ilabel symbol table (not owned)
-  SymbolTable *osyms_;           // olabel symbol table (not owned)
-  SymbolTable *ssyms_;           // slabel symbol table (not owned)
-  unordered_map<StateId, StateId> states_;  // state ID map
+  SymbolTable *isyms_;                 // ilabel symbol table (not owned)
+  SymbolTable *osyms_;                 // olabel symbol table (not owned)
+  SymbolTable *ssyms_;                 // slabel symbol table (not owned)
+  std::unordered_map<StateId, StateId> states_;  // state ID map
   StateId nstates_;                    // number of seen states
   bool keep_state_numbering_;
-  bool allow_negative_labels_;         // not recommended; may cause conflicts
-  bool add_symbols_;         // add to symbol tables on-the fly
+  bool allow_negative_labels_;  // not recommended; may cause conflicts
+  bool add_symbols_;            // add to symbol tables on-the fly
 
   DISALLOW_COPY_AND_ASSIGN(FstCompiler);
 };
